Installation
============

Python version
--------------

SunsetSettings requires Python 3.10 or later.


Installing from PyPI (recommended)
----------------------------------

SunsetSettings releases are available from `PyPI
<https://pypi.org/project/SunsetSettings/>`_ and can be installed with the standard
Python tooling.

Directly add ``SunsetSettings`` to your project's dependencies or, in order to manually
install SunsetSettings and make it available in the current Python prefix, run:

.. code:: shell

  pip install SunsetSettings


Installing from GitHub
----------------------

- Checkout the code:

  .. code:: shell

    git clone https://github.com/pvaret/SunsetSettings

- Build and install the library:

  .. code:: shell

    cd SunsetSettings ; pip install .

That's it!
